@@ -36,7 +36,7 @@
 
 
 #define SYSTEMDIR LOCALSTATEDIR "/lib/" PACKAGE 
-#define DIRHOME "/." PACKAGE
+#define DIRHOME "/." PACKAGE "-mount"
 #define LOCKFILENAME "/" PACKAGE ".lock"
 #define DEVICEFILENAME "/uditab"
 #define TMPPOSTFIX ".tmp"
@@ -597,29 +597,29 @@ halevt_mount_udi *halevt_mount_add_udi (char *udi, char *device, LibHalContext *
 void halevt_mount_rewrite_device_file (const char *tmp_device_file, const char *device_file)
 {
   FILE *out_fd;
-  if ((out_fd = fopen (tmp_device_file, "w")) == NULL)
-  {
-    fprintf (stderr, "Error opening %s: %s\n", tmp_device_file, strerror (errno));
-    exit (1);
-  }
-  if (! halevt_mount_print_udis (out_fd, 0)) { exit (1); }
+  struct stat statbuf;
   
   if (udi_device_mountpoint_root == NULL)
   {
-    if (unlink (tmp_device_file) < 0)
+    if (stat (device_file,  &statbuf) == 0)
     {
-      fprintf (stderr, "Cannot unlink %s: %s\n", tmp_device_file, strerror(errno));      
-    }
-    if (unlink (device_file) < 0)
-    {
-      fprintf (stderr, "Cannot unlink %s: %s\n", device_file, strerror(errno));      
+      if (unlink (device_file) < 0)
+      {
+        fprintf (stderr, "Cannot unlink %s: %s\n", device_file, strerror(errno));      
+      }
     }
   }
   else 
   {
+    if ((out_fd = fopen (tmp_device_file, "w")) == NULL)
+    {
+      fprintf (stderr, "Error opening %s: %s\n", tmp_device_file, strerror (errno));
+      exit (1);
+    }
+    if (! halevt_mount_print_udis (out_fd, 0)) { exit (1); }
     if (rename (tmp_device_file, device_file) <0)
     {
-      fprintf (stderr, "Regenerating %s failed: %s\n", device_file, strerror (errno));
+      fprintf (stderr, "Renaming %s to %s failed: %s\n", tmp_device_file, device_file, strerror (errno));
     }
   }
 }
@@ -1029,9 +1029,9 @@ int main (int argc, char **argv)
     if (! strcmp (cmd, "add")) 
     { 
     /* if we were just adding a new device we are done now */
-      if (rename (tmp_device_file, device_file) <0)
+      if (rename (tmp_device_file, device_file) < 0)
       {
-        fprintf (stderr, "Regenerating %s failed: %s\n", device_file, strerror (errno));
+        fprintf (stderr, "Renaming %s to %s after add failed: %s\n", tmp_device_file, device_file, strerror (errno));
         exit (1); 
       }
       goto end; 
@@ -1066,7 +1066,7 @@ int main (int argc, char **argv)
     halevt_mount_check_dbus_error (&dbus_error);
     if (rename (tmp_device_file, device_file) <0)
     {
-      fprintf (stderr, "Regenerating %s failed: %s\n", device_file, strerror (errno));
+      fprintf (stderr, "Renaming %s to %s after a mount failed: %s\n", tmp_device_file, device_file, strerror (errno));
     }
   }
   else if ((! strcmp (cmd, "umount")) || (! strcmp (cmd, "clean")))
@@ -1132,7 +1132,7 @@ int main (int argc, char **argv)
           }
         }
       }
-      else { fprintf (stderr, "Nothing found to be processed\n"); }
+    /*  else { fprintf (stderr, "Nothing found to be processed\n"); } */
     }
     /* when umounting we don't write to the device file, to avoid messing
      with file permissions in case the umount was done as root */
@@ -1145,7 +1145,8 @@ int main (int argc, char **argv)
 end:
   if (unlink (lockfile) <0)
   {
-    fprintf (stderr, "Cannot unlink %s: %s\n", lockfile, strerror(errno));
+  /*  Another process may have already removed the file */
+  /*  fprintf (stderr, "Cannot unlink %s: %s\n", lockfile, strerror(errno)); */
   }
   
   if (close (fd_lock) <0)
